<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns="urn:hl7-org:v3" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" xmlns:hl7="urn:hl7-org:v3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xs="http://www.w3.org/2001/XMLSchema">
    <xsl:output method="xml" indent="yes" exclude-result-prefixes="#all"/>
    <xsl:strip-space elements="*"/>
    <!-- Transforms MP 9.04 message/CDA into MP 9.05 -->

    <!-- Issue 294. Gebruikindicator bij Medicatiegebruik niet mappen op negationInd -->
    <!-- Allereerst is een nieuw template voor Medicatiegebruik gekomen en daardoor ook voor de aanroepende templates
        , dus met een nieuw templateId -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9104']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9192'"/>
    </xsl:template>
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9125']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9191'"/>
    </xsl:template>
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9132']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9193'"/>
    </xsl:template>
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9133']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9197'"/>
    </xsl:template>
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9134']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9195'"/>
    </xsl:template>
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9138']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9198'"/>
    </xsl:template>
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9139']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9196'"/>
    </xsl:template>
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9146']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9199'"/>
    </xsl:template>
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9147']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9194'"/>
    </xsl:template>
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9154']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9190'"/>
    </xsl:template>
    <!-- Issue 294. Dan de Gebruikindicator zélf (bij Medicatiegebruik niet mappen op negationInd) -->
    <!-- negationInd verwijderen - omdat we negationInd niet (meer) gebruiken -->
    <xsl:template match="hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9154']]/@negationInd"/>
    <!-- dan gebruikindicator toevoegen als eerste entryRelationship -->
    <xsl:template match="hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9154']]/hl7:entryRelationship[1]">
        <xsl:variable name="booleanGebruik" select="(not(../@negationInd) or (../@negationInd != 'true'))"/>
        <entryRelationship typeCode="COMP">
            <observation classCode="OBS" moodCode="EVN">
                <templateId root="2.16.840.1.113883.2.4.3.11.60.20.77.10.9189"/>
                <code displayName="Gebruikindicator" code="15" codeSystem="2.16.840.1.113883.2.4.3.11.60.20.77.5.2"/>
                <value xsi:type="BL">
                    <xsl:attribute name="value" select="$booleanGebruik"/>
                </value>
            </observation>
        </entryRelationship>
        <!-- Vanaf de bestaande entryRelationship weer alles kopiëren -->
        <xsl:copy>
            <xsl:apply-templates select="@* | node()"/>
        </xsl:copy>
    </xsl:template>
    <!-- Einde issue 294 -->
    
    <!-- Issue 298, 302, - geen conversie nodig in instances -->
    
    <!-- Issue 304 - consumable bij medicatiegebruik minder streng, en daardoor ander template Id -->
    <xsl:template match="hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9154']]/hl7:consumable/hl7:manufacturedProduct/hl7:templateId">
        <xsl:copy>
            <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9163'"></xsl:attribute>
        </xsl:copy>
    </xsl:template>
    

    <!-- Issue 307, 308 - geen conversie nodig in instances -->
    
    <!-- Issue 309 Bij Voorstel verstrekkingsverzoek ontbrak code element -->
    <xsl:template match="hl7:supply[hl7:templateId/@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9131'][not(hl7:code)]/hl7:templateId">
        <xsl:copy-of select="." exclude-result-prefixes="#all"/>
        <!-- stel dat er wel een id is meegegeven (niet gedefinieerd in template bij voorstel vv, maar mag wel in open template), dan deze kopiëren voor de code -->
        <xsl:copy-of select="../id" exclude-result-prefixes="#all"/>
        <code code="3" codeSystem="2.16.840.1.113883.2.4.3.11.60.20.77.5.3" displayName="Verstrekkingsverzoek"/>
    </xsl:template>
    
    <!-- Issue 310 - geen conversie nodig in instances -->




    <!-- Default copy xsl template -->
    <xsl:template match="@* | node()">
        <xsl:copy>
            <xsl:apply-templates select="@* | node()"/>
        </xsl:copy>
    </xsl:template>
</xsl:stylesheet>
